@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-favicon-cache.c,v 1.20.2.2 2003/12/18 12:48:42 chpe Exp $
  */
 
 #include <libxml/tree.h>
@@ -29,7 +31,7 @@
 #include "ephy-node.h"
 #include "ephy-debug.h"
 
-#define EPHY_FAVICON_CACHE_XML_VERSION "0.1"
+#define EPHY_FAVICON_CACHE_XML_VERSION "1.0"
 
 #define EPHY_FAVICON_CACHE_OBSOLETE_DAYS 30
 
@@ -44,7 +46,6 @@ struct EphyFaviconCachePrivate
 	EphyNodeDb *db;
 	EphyNode *icons;
 	GHashTable *icons_hash;
-	GStaticRWLock *icons_hash_lock;
 	GHashTable *downloads_hash;
 };
 
@@ -124,20 +125,19 @@ ephy_favicon_cache_load (EphyFaviconCache *eb)
 {
 	xmlDocPtr doc;
 	xmlNodePtr root, child;
-	char *tmp;
 
 	if (g_file_test (eb->priv->xml_file, G_FILE_TEST_EXISTS) == FALSE)
 		return;
 
 	doc = xmlParseFile (eb->priv->xml_file);
-	g_assert (doc != NULL);
+	if (doc == NULL)
+	{
+		g_warning ("Failed to load favicon cache.\n");
+		return;
+	}
 
 	root = xmlDocGetRootElement (doc);
 
-	tmp = xmlGetProp (root, "version");
-	g_assert (tmp != NULL && strcmp (tmp, EPHY_FAVICON_CACHE_XML_VERSION) == 0);
-	g_free (tmp);
-
 	for (child = root->children; child != NULL; child = child->next)
 	{
 		EphyNode *node;
@@ -169,13 +169,9 @@ icons_added_cb (EphyNode *node,
 	        EphyNode *child,
 	        EphyFaviconCache *eb)
 {
-	g_static_rw_lock_writer_lock (eb->priv->icons_hash_lock);
-
 	g_hash_table_insert (eb->priv->icons_hash,
 			     (char *) ephy_node_get_property_string (child, EPHY_NODE_FAVICON_PROP_URL),
 			     child);
-
-	g_static_rw_lock_writer_unlock (eb->priv->icons_hash_lock);
 }
 
 static void
@@ -183,12 +179,8 @@ icons_removed_cb (EphyNode *node,
 		  EphyNode *child,
 		  EphyFaviconCache *eb)
 {
-	g_static_rw_lock_writer_lock (eb->priv->icons_hash_lock);
-
 	g_hash_table_remove (eb->priv->icons_hash,
 			     ephy_node_get_property_string (child, EPHY_NODE_FAVICON_PROP_URL));
-
-	g_static_rw_lock_writer_unlock (eb->priv->icons_hash_lock);
 }
 
 static void
@@ -204,7 +196,6 @@ remove_obsolete_icons (EphyFaviconCache *eb)
         g_date_set_time (&current_date, time (NULL));
 
 	children = ephy_node_get_children (eb->priv->icons);
-	ephy_node_thaw (eb->priv->icons);
 	for (i = 0; i < children->len; i++)
 	{
 		EphyNode *kid;
@@ -251,7 +242,6 @@ ephy_favicon_cache_save (EphyFaviconCache *eb)
 
 		ephy_node_save_to_xml (kid, root);
 	}
-	ephy_node_thaw (eb->priv->icons);
 
 	ephy_file_save_xml (eb->priv->xml_file, doc);
 
@@ -265,7 +255,7 @@ ephy_favicon_cache_init (EphyFaviconCache *cache)
 
 	cache->priv = g_new0 (EphyFaviconCachePrivate, 1);
 
-	db = ephy_node_db_new ("EphyFaviconCache");
+	db = ephy_node_db_new (EPHY_NODE_DB_SITEICONS);
 	cache->priv->db = db;
 
 	cache->priv->xml_file = g_build_filename (ephy_dot_dir (),
@@ -285,9 +275,7 @@ ephy_favicon_cache_init (EphyFaviconCache *cache)
 	}
 
 	cache->priv->icons_hash = g_hash_table_new (g_str_hash,
-			                            g_str_equal);
-	cache->priv->icons_hash_lock = g_new0 (GStaticRWLock, 1);
-	g_static_rw_lock_init (cache->priv->icons_hash_lock);
+						    g_str_equal);
 	cache->priv->downloads_hash = g_hash_table_new_full (g_str_hash,
 			                                     g_str_equal,
 							     g_free,
@@ -320,9 +308,7 @@ kill_download (gpointer key,
 	ephy_embed_persist_cancel (persist);
 	g_object_unref (persist);
 
-	g_static_rw_lock_reader_lock (cache->priv->icons_hash_lock);
 	icon = g_hash_table_lookup (cache->priv->icons_hash, (char *)key);
-	g_static_rw_lock_reader_unlock (cache->priv->icons_hash_lock);
 
 	ephy_node_unref (icon);
 
@@ -358,7 +344,6 @@ ephy_favicon_cache_finalize (GObject *object)
 	g_free (cache->priv->xml_file);
 	g_free (cache->priv->directory);
 	g_hash_table_destroy (cache->priv->icons_hash);
-	g_static_rw_lock_free (cache->priv->icons_hash_lock);
 	g_hash_table_destroy (cache->priv->downloads_hash);
 
 	g_object_unref (cache->priv->db);
@@ -388,13 +373,15 @@ favicon_download_completed_cb (EphyEmbedPersist *persist,
 {
 	char *url;
 
-	url = g_object_get_data (G_OBJECT (persist), "url");
+	url = g_strdup ((char *) g_object_get_data (G_OBJECT (persist), "url"));
 	g_return_if_fail (url != NULL);
 
-	g_signal_emit (G_OBJECT (cache), ephy_favicon_cache_signals[CHANGED], 0, url);
-
 	g_hash_table_remove (cache->priv->downloads_hash, url);
 	g_object_unref (persist);
+
+	g_signal_emit (G_OBJECT (cache), ephy_favicon_cache_signals[CHANGED], 0, url);
+
+	g_free (url);
 }
 
 static void
@@ -450,9 +437,7 @@ ephy_favicon_cache_get (EphyFaviconCache *cache,
 
 	now = time (NULL);
 
-	g_static_rw_lock_reader_lock (cache->priv->icons_hash_lock);
 	icon = g_hash_table_lookup (cache->priv->icons_hash, url);
-	g_static_rw_lock_reader_unlock (cache->priv->icons_hash_lock);
 
 	if (!icon)
 	{
