@@ -6,7 +6,10 @@
 #include <nsIWebBrowserChrome.h>
 #include <gtkmozembed.h>
 
-GtkWidget *MozillaFindGtkParent (nsIDOMWindow *aDOMWindow)
+#include "ephy-embed.h"
+#include "mozilla-embed.h"
+
+GtkWidget *MozillaFindEmbed (nsIDOMWindow *aDOMWindow)
 {
         nsresult result;
 
@@ -14,12 +17,20 @@ GtkWidget *MozillaFindGtkParent (nsIDOMWindow *aDOMWindow)
                 (do_GetService("@mozilla.org/embedcomp/window-watcher;1"));
         if (!wwatch) return nsnull;
 
- 	nsCOMPtr<nsIDOMWindow> domWindow(aDOMWindow);
-	if (!domWindow)
+ 	nsCOMPtr<nsIDOMWindow> domWindow;
+	if (aDOMWindow)
 	{
-		result = wwatch->GetActiveWindow(getter_AddRefs(domWindow));
-		if (NS_FAILED(result) || !domWindow) return nsnull;
+		/* this DOM window may belong to some inner frame, we need
+		 * to get the topmost DOM window to get the embed
+		 */
+		aDOMWindow->GetTop (getter_AddRefs (domWindow));
 	}
+	else
+	{
+		/* get the active window */
+		wwatch->GetActiveWindow (getter_AddRefs(domWindow));
+	}
+	NS_ENSURE_TRUE (domWindow, nsnull);
 	
         nsCOMPtr<nsIWebBrowserChrome> windowChrome;
         result = wwatch->GetChromeForWindow (domWindow,
@@ -34,7 +45,15 @@ GtkWidget *MozillaFindGtkParent (nsIDOMWindow *aDOMWindow)
         result = window->GetSiteWindow ((void **)&mozembed);
         if (NS_FAILED(result)) return nsnull;
 
-	return gtk_widget_get_toplevel (GTK_WIDGET(mozembed));
+	return mozembed;
+}
+
+GtkWidget *MozillaFindGtkParent (nsIDOMWindow *aDOMWindow)
+{
+	GtkWidget *embed = MozillaFindEmbed (aDOMWindow);
+	if (!embed) return nsnull;
+
+	return gtk_widget_get_toplevel (GTK_WIDGET (embed));
 }
 
 #define MM_TO_INCH(x)		(((double) x) / 25.4)
