@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node.h,v 1.12 2003/05/26 23:03:57 xan Exp $
+ *  $Id: ephy-node.h,v 1.12.2.1 2003/12/18 12:48:42 chpe Exp $
  */
 
 
@@ -60,10 +60,6 @@ long        ephy_node_get_id                (EphyNode *node);
 void        ephy_node_ref                   (EphyNode *node);
 void        ephy_node_unref                 (EphyNode *node);
 
-/* locking */
-void        ephy_node_freeze                (EphyNode *node);
-void        ephy_node_thaw                  (EphyNode *node);
-
 /* signals */
 int         ephy_node_signal_connect_object (EphyNode *node,
 					     EphyNodeSignalType type,
