@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-favicon-action.c,v 1.15.2.1 2003/12/15 11:39:59 chpe Exp $
  */
 
 #include "ephy-favicon-action.h"
@@ -87,7 +89,6 @@ each_url_get_data_binder (EphyDragEachSelectedItemDataGet iteratee,
 {
 	const char *title;
 	char *location;
-	char *netscape_url;
 	EphyTab *tab;
 	EphyEmbed *embed;
 	EphyWindow *window = EPHY_WINDOW(iterator_context);
@@ -97,11 +98,8 @@ each_url_get_data_binder (EphyDragEachSelectedItemDataGet iteratee,
 	ephy_embed_get_location (embed, TRUE, &location);
 	title = ephy_tab_get_title (tab);
 
-	netscape_url = g_strconcat (location, "\n", title, NULL);
+	iteratee (location, title, data);
 
-	iteratee (netscape_url, -1, -1, -1, -1, data);
-
-	g_free (netscape_url);
 	g_free (location);
 }
 
