@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.c,v 1.54 2003/08/06 09:47:55 chpe Exp $
+ *  $Id: ephy-shell.c,v 1.54.2.5 2003/12/20 12:02:36 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -31,7 +31,6 @@
 #include "ephy-stock-icons.h"
 #include "ephy-window.h"
 #include "ephy-file-helpers.h"
-#include "ephy-thread-helpers.h"
 #include "ephy-bookmarks-import.h"
 #include "ephy-bookmarks-editor.h"
 #include "ephy-history-window.h"
@@ -70,6 +69,7 @@ struct EphyShellPrivate
 	GtkWidget *bme;
 	GtkWidget *history_window;
 	GList *plugins;
+	gboolean server_mode;
 };
 
 static void
@@ -200,13 +200,13 @@ ephy_shell_init (EphyShell *gs)
 	gs->priv->history_window = NULL;
 	gs->priv->toolbars_model = NULL;
 	gs->priv->plugins = NULL;
+	gs->priv->server_mode = FALSE;
 
 	ephy_shell = gs;
 	g_object_add_weak_pointer (G_OBJECT(ephy_shell),
 				   (gpointer *)ptr);
 
 	ephy_debug_init ();
-	ephy_thread_helpers_init ();
 	ephy_file_helpers_init ();
 	ephy_stock_icons_init ();
 	ephy_ensure_dir_exists (ephy_dot_dir ());
@@ -326,6 +326,7 @@ ephy_init_services (EphyShell *gs)
 	/* it also enables notifiers support */
 	eel_gconf_monitor_add ("/apps/epiphany");
 	eel_gconf_monitor_add ("/system/proxy");
+	eel_gconf_monitor_add ("/system/http_proxy");
 
 #ifdef ENABLE_NAUTILUS_VIEW
 
@@ -660,3 +661,28 @@ ephy_shell_show_history_window (EphyShell *gs,
 
 	gtk_window_present (GTK_WINDOW (gs->priv->history_window));
 }
+
+gboolean
+ephy_shell_get_server_mode (EphyShell *es)
+{
+	g_return_val_if_fail (IS_EPHY_SHELL (es), FALSE);
+
+	return es->priv->server_mode;
+}
+
+void
+ephy_shell_set_server_mode (EphyShell *es, gboolean as_server)
+{
+	g_return_if_fail (IS_EPHY_SHELL (es));
+
+	if (es->priv->server_mode == FALSE && as_server == TRUE)
+	{
+		g_object_ref (G_OBJECT (es));
+	}
+	else if (es->priv->server_mode == TRUE && as_server == FALSE)
+	{
+		g_object_unref (G_OBJECT (es));
+	}
+
+	es->priv->server_mode = as_server;
+}
