@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-toolbars-model.c,v 1.16 2003/08/08 16:21:18 mpeseng Exp $
+ *  $Id: ephy-toolbars-model.c,v 1.17.2.1 2003/11/10 01:40:52 chpe Exp $
  */
 
 #include "ephy-toolbars-model.h"
@@ -28,6 +28,7 @@
 #include "ephy-string.h"
 
 #include <string.h>
+#include <bonobo/bonobo-i18n.h>
 
 static void ephy_toolbars_model_class_init (EphyToolbarsModelClass *klass);
 static void ephy_toolbars_model_init       (EphyToolbarsModel *t);
@@ -188,8 +189,15 @@ impl_get_item_id (EggToolbarsModel *t,
 			/* Create the bookmark, it does not exist */
 			EphyHistory *gh;
 			const char *icon;
+			const char *title;
 
-			node = ephy_bookmarks_add (bookmarks, netscape_url[NAME], netscape_url[URL]);
+			title = netscape_url[NAME];
+			if (title == NULL || *title == '\0')
+			{
+				title = _("Untitled");
+			}
+
+			node = ephy_bookmarks_add (bookmarks, title, netscape_url[URL]);
 			g_return_val_if_fail (node != NULL, NULL);
 
 			gh = ephy_embed_shell_get_global_history (EPHY_EMBED_SHELL (ephy_shell));
@@ -313,6 +321,7 @@ static void
 ephy_toolbars_model_set_bookmarks (EphyToolbarsModel *model, EphyBookmarks *bookmarks)
 {
 	EggToolbarsModel *egg_model = EGG_TOOLBARS_MODEL (model);
+	gboolean success = FALSE;
 
 	model->priv->bookmarks = bookmarks;
 	g_object_ref (model->priv->bookmarks);
@@ -321,10 +330,11 @@ ephy_toolbars_model_set_bookmarks (EphyToolbarsModel *model, EphyBookmarks *book
 
 	if (g_file_test (model->priv->xml_file, G_FILE_TEST_EXISTS))
 	{
-		egg_toolbars_model_load (egg_model,
+		success = egg_toolbars_model_load (egg_model,
 					 model->priv->xml_file);
 	}
-	else
+
+	if (success == FALSE)
 	{
 		const char *default_xml;
 
