@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.c,v 1.102.2.1 2003/09/26 16:04:26 marco Exp $
+ *  $Id: ephy-window.c,v 1.102.2.3 2004/01/10 22:07:42 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -470,6 +470,8 @@ update_exit_fullscreen_popup_position (EphyWindow *window)
 	GdkRectangle screen_rect;
 	int popup_height;
 
+	g_return_if_fail (window->priv->exit_fullscreen_popup != NULL);
+
 	gtk_window_get_size (GTK_WINDOW (window->priv->exit_fullscreen_popup),
                              NULL, &popup_height);
 
@@ -581,7 +583,7 @@ ephy_window_fullscreen (EphyWindow *window)
 
 	g_signal_connect (G_OBJECT (gdk_screen_get_default ()),
                           "size-changed", G_CALLBACK (size_changed_cb),
-			  popup);
+			  window);
 
 	update_chromes_visibility (window, window->priv->chrome_mask);
 }
@@ -1087,10 +1089,12 @@ show_embed_popup (EphyWindow *window, EphyTab *tab, EphyEmbedEvent *event)
 	{
 		popup = "EphyImagePopup";
 	}
-/*	else if (context & EMBED_CONTEXT_INPUT)
+#if MOZILLA_SNAPSHOT > 12
+	else if (context & EMBED_CONTEXT_INPUT)
 	{
 		popup = "EphyInputPopup";
-	}*/
+	}
+#endif
 	else
 	{
 		popup = framed ? "EphyFramedDocumentPopup" :
