@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: pdm-dialog.c,v 1.17 2003/07/14 14:22:37 chpe Exp $
+ * $Id: pdm-dialog.c,v 1.19 2003/07/27 12:26:10 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -242,6 +242,9 @@ setup_passwords_treeview (PdmDialog *dialog)
 	selection = gtk_tree_view_get_selection (treeview);
 	gtk_tree_selection_set_mode (selection,
 				     GTK_SELECTION_MULTIPLE);
+	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (liststore),
+					      COL_PASSWORDS_HOST,
+					      GTK_SORT_ASCENDING);
 
         renderer = gtk_cell_renderer_text_new ();
 
@@ -295,6 +298,9 @@ setup_cookies_treeview (PdmDialog *dialog)
 	selection = gtk_tree_view_get_selection (treeview);
 	gtk_tree_selection_set_mode (selection,
 				     GTK_SELECTION_MULTIPLE);
+	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (liststore),
+					      COL_COOKIES_HOST,
+					      GTK_SORT_ASCENDING);
 
 	g_signal_connect (selection, "changed",
 			  G_CALLBACK(cookies_treeview_selection_changed_cb),
@@ -424,9 +430,14 @@ pdm_cmd_delete_selection (PdmActionInfo *action)
 	if (row_ref != NULL)
 	{
 		path = gtk_tree_row_reference_get_path (row_ref);
-		gtk_tree_view_set_cursor (GTK_TREE_VIEW (action->treeview), path, NULL, FALSE);
+
+		if (path != NULL)
+		{
+			gtk_tree_view_set_cursor (GTK_TREE_VIEW (action->treeview), path, NULL, FALSE);
+			gtk_tree_path_free (path);
+		}
+
 		gtk_tree_row_reference_free (row_ref);
-		gtk_tree_path_free (path);
 	}
 }
 
