@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.74 2003/08/05 22:55:13 chpe Exp $
+ *  $Id: window-commands.c,v 1.76.2.4 2003/12/22 15:35:33 chpe Exp $
  */
 
 #include <config.h>
@@ -79,6 +79,8 @@ window_cmd_go_back (EggAction *action,
 	embed = ephy_window_get_active_embed (window);
 	g_return_if_fail (embed != NULL);
 
+	ephy_embed_activate (embed);
+
 	ephy_embed_go_back (embed);
 }
 
@@ -91,6 +93,8 @@ window_cmd_go_up (EggAction *action,
 	embed = ephy_window_get_active_embed (window);
 	g_return_if_fail (embed != NULL);
 
+	ephy_embed_activate (embed);
+
 	ephy_embed_go_up (embed);
 }
 
@@ -146,6 +150,8 @@ window_cmd_go_forward (EggAction *action,
 	embed = ephy_window_get_active_embed (window);
 	g_return_if_fail (embed != NULL);
 
+	ephy_embed_activate (embed);
+
 	ephy_embed_go_forward (embed);
 }
 
@@ -185,6 +191,8 @@ window_cmd_view_stop (EggAction *action,
 	embed = ephy_window_get_active_embed (window);
 	g_return_if_fail (embed != NULL);
 
+	ephy_embed_activate (embed);
+
 	ephy_embed_stop_load (embed);
 }
 
@@ -202,24 +210,29 @@ window_cmd_view_reload (EggAction *action,
 	g_return_if_fail (embed != NULL);
 
 	event = gtk_get_current_event ();
-	type = event->type;
-
-	if (type == GDK_BUTTON_RELEASE)
+	if (event)
 	{
-		state = event->button.state; 
-	}
-	else if (type == GDK_KEY_RELEASE)
-	{
-		state = event->key.state;
-	}
+		type = event->type;
 
-	gdk_event_free (event);
+		if (type == GDK_BUTTON_RELEASE)
+		{
+			state = event->button.state; 
+		}
+		else if (type == GDK_KEY_RELEASE)
+		{
+			state = event->key.state;
+		}
+
+		gdk_event_free (event);
+	}
 
 	if (state & GDK_SHIFT_MASK)
 	{
 		force = TRUE;
 	}
 
+	ephy_embed_activate (embed);
+
 	ephy_embed_reload (embed, force ? EMBED_RELOAD_NORMAL
 					: EMBED_RELOAD_BYPASSCACHE);
 }
@@ -308,10 +321,7 @@ void
 window_cmd_file_open (EggAction *action,
 		      EphyWindow *window)
 {
-	gchar *dir, *retDir;
-        gchar *file;
-        GnomeVFSURI *uri;
-	GtkWidget *wmain;
+	char *dir, *ret_dir, *file;
 	EphyEmbedShell *embed_shell;
 	gresult result;
 	EphyEmbedSingle *single;
@@ -321,35 +331,37 @@ window_cmd_file_open (EggAction *action,
 
 	embed_shell = EPHY_EMBED_SHELL (ephy_shell);
 
-	wmain = GTK_WIDGET (window);
-	g_return_if_fail (wmain != NULL);
-
         dir = eel_gconf_get_string (CONF_STATE_OPEN_DIR);
 
 	result = ephy_embed_single_show_file_picker
-		(single, wmain,
+		(single, GTK_WIDGET (window),
 		 _("Open"),
                  dir, NULL, modeOpen,
                  &file, NULL, NULL);
 
-	uri = gnome_vfs_uri_new (file);
-	if (uri)
+	/* persist directory choice */
+	/* Fix for bug 122780:
+	 * if the user selected a directory, or aborted with no filename typed,
+	 * g_path_get_dirname and gnome_vfs_uri_extract_dirname strip the last
+	 * path component, so test if the returned file is actually a directory.
+	 */
+	if (g_file_test (file, G_FILE_TEST_IS_DIR))
 	{
-		retDir = gnome_vfs_uri_extract_dirname (uri);
-
-		/* set default open dir */
-		eel_gconf_set_string (CONF_STATE_OPEN_DIR,
-				      retDir);
-
-		g_free (retDir);
-		gnome_vfs_uri_unref (uri);
-
-		if (result == G_OK)
-		{
-			ephy_window_load_url(window, file);
-	        }
+		ret_dir = g_strdup (file);
+	}
+	else
+	{
+		ret_dir = g_path_get_dirname (file);
 	}
 
+	eel_gconf_set_string (CONF_STATE_OPEN_DIR, ret_dir);
+
+	if (result == G_OK)
+	{
+		ephy_window_load_url(window, file);
+        }
+
+	g_free (ret_dir);
 	g_free (file);
         g_free (dir);
 }
@@ -737,10 +749,10 @@ window_cmd_help_about (EggAction *action,
 	GnomeIconTheme *icon_theme;
 
 	static gchar *authors[] = {
-		"Marco Pesenti Gritti <mpeseng@tin.it>",
-		"Xan Lopez <xan@masilla.org>",
+		"Marco Pesenti Gritti <marco@gnome.org>",
+		"Xan Lopez <xan@gnome.org>",
 		"David Bordoley <bordoley@msu.edu>",
-		"Christian Persch <chpe+epiphany@stud.uni-saarland.de>",
+		"Christian Persch <chpe@gnome.org>",
 		NULL
 	};
 
